package com.bsoft.admin.service.impl;

import com.bsoft.admin.common.enums.StateType;
import com.bsoft.admin.mapper.SysUserMapper;
import com.bsoft.admin.model.SysUser;
import com.bsoft.admin.model.reqmodel.UserReq;
import com.bsoft.admin.service.UserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class UserServiceImpl implements UserService {

    @Resource
    private SysUserMapper sysUserMapper;

    @Override
    public SysUser findByLoginName(String loginName) {
        return sysUserMapper.selectByCode(loginName);
    }

    @Override
    public boolean addUser(Long userId, UserReq.AddUserReq user){
        if(user!=null) {
            SysUser sysUser = new SysUser();
            sysUser.setUserCode(user.getUserCode());
            sysUser.setUserName(user.getUserName());
            sysUser.setPassword(user.getPassword());
            sysUser.setIdcard(user.getIdcard());
            sysUser.setMobile(user.getMobile());
            sysUser.setSex(user.getSex());
            sysUser.setCreateDate(new Date());
            sysUser.setCreateUserid(userId);
            sysUser.setState((short) StateType.ON.getValue());
            sysUserMapper.insert(sysUser);
            return true;
        }
        return false;
    }

    @Override
    public boolean deleteUser(UserReq.DeleteUserReq user) {
        if(user!=null){
            SysUser sysUser = sysUserMapper.selectByPrimaryKey(user.getUserId());
            if(sysUser!=null){
                sysUser.setState((short)StateType.OFF.getValue());
                sysUserMapper.updateByPrimaryKey(sysUser);
                return true;
            }
        }
        return false;
    }

    @Override
    public boolean updateUser(UserReq.UpdateUserReq user) {
        if(user!=null){
            SysUser sysUser = sysUserMapper.selectByPrimaryKey(user.getUserId());
            if(sysUser!=null){
                sysUser.setUserCode(user.getUserCode());
                sysUser.setUserName(user.getUserName());
                sysUser.setPassword(user.getPassword());
                sysUser.setIdcard(user.getIdcard());
                sysUser.setMobile(user.getMobile());
                sysUser.setSex(user.getSex());
                sysUserMapper.updateByPrimaryKey(sysUser);
                return true;
            }
        }
        return false;
    }

    @Override
    public List<SysUser> getAll(UserReq.GetUserReq user) {
        List<SysUser> list = sysUserMapper.selectAll();
        if(user.getUserName()!=null){
            list = list.stream().filter(
                    o->(o.getUserName()!=null && o.getUserName().toLowerCase().contains(user.getUserName().toLowerCase())))
                    .collect(Collectors.toList());
        }
        return list;
    }

    @Override
    public SysUser info(Long userId) {
        SysUser sysUser=sysUserMapper.selectByPrimaryKey(userId);
        return sysUser;
    }
}
